#
# spec file for package hcloud-cli
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define executable_name hcloud

Name:           hcloud-cli
Version:        1.50.0
Release:        1.2
Summary:        A command-line interface for Hetzner Cloud
License:        MIT
URL:            https://github.com/hetznercloud/cli
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.22
BuildRequires:  zsh
Provides:       hcloud = %{version}

%description
hcloud is a command-line interface for interacting with Hetzner Cloud.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -trimpath \
   -ldflags=" \
   -X github.com/hetznercloud/cli/internal/version.version=%{version} \
   -X github.com/hetznercloud/cli/internal/version.versionPrerelease=" \
   -o bin/%{executable_name} ./cmd/hcloud/main.go

%install
# Install the binary.
install -D -m 0755 bin/%{executable_name} %{buildroot}/%{_bindir}/%{executable_name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{executable_name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{executable_name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{executable_name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{executable_name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{executable_name}

%check
%{buildroot}/%{_bindir}/%{executable_name} version
%{buildroot}/%{_bindir}/%{executable_name} version | grep %{version}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{executable_name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{executable_name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{executable_name}

%changelog
* Fri Jan 17 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.50.0:
  * chore(main): release v1.50.0 (#936)
  * test: add ISO e2e tests (#953)
  * deps: update module github.com/goccy/go-yaml to v1.15.14 (#956)
  * test: add Load Balancer Type e2e tests (#954)
  * deps: update module golang.org/x/crypto to v0.32.0 (#952)
  * deps: update module golang.org/x/term to v0.28.0 (#951)
  * deps: update dependency golangci/golangci-lint to v1.63.4
    (#950)
  * test(e2e): add e2e tests for certificate resource (#945)
  * feat(certificate): allow adding labels during create (#949)
  * test(e2e): add ssh key e2e tests (#947)
  * deps: update dependency golangci/golangci-lint to v1.63.3
    (#948)
  * deps: update dependency golangci/golangci-lint (#946)
  * deps: update module github.com/goccy/go-yaml to v1.15.13 (#944)
  * deps: update module github.com/goccy/go-yaml to v1.15.12 (#943)
  * deps: update module github.com/hetznercloud/hcloud-go/v2 to
    v2.17.1 (#940)
  * deps: update module github.com/spf13/cast to v1.7.1 (#942)
  * deps: update module github.com/goccy/go-yaml to v1.15.11 (#941)
  * deps: update module github.com/goccy/go-yaml to v1.15.10 (#939)
  * deps: update module github.com/jedib0t/go-pretty/v6 to v6.6.5
    (#938)
  * deps: update module github.com/goccy/go-yaml to v1.15.9 (#937)
  * deps: update module golang.org/x/crypto to v0.31.0 (#931)
  * deps: update module golang.org/x/term to v0.27.0 (#930)
  * fix: display $ when the currency is USD (#933)
  * deps: update module github.com/jedib0t/go-pretty/v6 to v6.6.4
    (#935)
  * deps: update module github.com/goccy/go-yaml to v1.15.8 (#934)
  * deps: update module github.com/goccy/go-yaml to v1.15.7 (#932)
  * deps: update dependency go to v1.23.4 (#929)
  * deps: update module github.com/goccy/go-yaml to v1.15.6 (#928)
  * deps: update module github.com/goccy/go-yaml to v1.15.5 (#927)
  * deps: update module github.com/goccy/go-yaml to v1.15.4 (#926)
  * deps: update module github.com/goccy/go-yaml to v1.15.3 (#924)
  * deps: update module github.com/stretchr/testify to v1.10.0
    (#922)
  * deps: update module github.com/hetznercloud/hcloud-go/v2 to
    v2.17.0 (#921)
  * deps: update module github.com/jedib0t/go-pretty/v6 to v6.6.3
    (#925)
  * deps: update dependency golangci/golangci-lint to v1.62.2
    (#923)
  * deps: update module github.com/jedib0t/go-pretty/v6 to v6.6.2
    (#920)
  * deps: update apricote/releaser-pleaser action to v0.5.0 (#919)
  * deps: update codecov/codecov-action action to v5 (#915)
  * deps: update module github.com/goccy/go-yaml to v1.14.3 (#917)
  * deps: update module github.com/goccy/go-yaml to v1.14.2 (#916)
  * deps: update module github.com/goccy/go-yaml to v1.14.1 (#914)
  * deps: update module github.com/goccy/go-yaml to v1.13.8 (#913)
  * deps: update dependency golangci/golangci-lint (#912)
  * deps: update module github.com/anchore/quill to v0.5.0 (#910)
  * deps: update module github.com/goccy/go-yaml to v1.13.7 (#911)
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.49.0:
  * chore(main): release v1.49.0 (#909)
  * chore(main): release v1.49.0-rc.0 (#908)
  * deps: update releaser-pleaser to v0.4.2 (#907)
  * ci: switch to releaser-pleaser (#906)
  * chore: replace deprecated goreleaser config property (#905)
  * ci: download go tools before running them (#904)
  * fix: replace archived github.com/golang/mock with
    go.uber.org/mock (#903)
  * chore: move tools to module to prevent bloating the root module
    (#901)
  * feat: drop support for go 1.21 (#902)
  * deps: update module golang.org/x/crypto to v0.29.0 (#899)
  * deps: update module golang.org/x/term to v0.26.0 (#900)
  * deps: update dependency go to v1.23.3
  * deps: update module github.com/goccy/go-yaml to v1.13.6
  * deps: update module github.com/hetznercloud/hcloud-go/v2 to
    v2.16.0 (#896)
  * deps: update module github.com/goccy/go-yaml to v1.13.5
  * deps: update module github.com/goccy/go-yaml to v1.13.4
  * deps: update module github.com/goccy/go-yaml to v1.13.3
  * deps: update module github.com/goccy/go-yaml to v1.13.2
  * deps: update module github.com/hetznercloud/hcloud-go/v2 to
    v2.15.0 (#891)
  * fix: macOS binary not notarized (#868)
  * deps: update module github.com/goccy/go-yaml to v1.13.1
  * deps: update module github.com/goccy/go-yaml to v1.13.0 (#888)
  * deps: update module github.com/guptarohit/asciigraph to v0.7.3
* Fri Oct 25 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.48.0:
  * chore(main): release 1.48.0 (#867)
  * deps: update module github.com/hetznercloud/hcloud-go/v2 to
    v2.14.0 (#882)
  * deps: update module github.com/fatih/color to v1.18.0 (#884)
  * fix(primary-ip): labels ignored in create command (#885)
  * deps: update module github.com/jedib0t/go-pretty/v6 to v6.6.1
    (#876)
  * deps: update module github.com/boumenot/gocover-cobertura to
    v1.3.0 (#881)
  * test(e2e): add back check for uniqueness_error in network test
    (#879)
  * deps: update module golang.org/x/crypto to v0.28.0 (#878)
  * deps: update dependency go to v1.23.2
  * test(e2e): use builder for regexes (#872)
  * chore: delete unused workflow file (#873)
  * test(e2e): add end to end testing (#785)
  * ci: build and test with Go 1.23 (#871)
  * refactor: prepare for e2e tests (#870)
  * feat: allow auto-completing context flag (#861)
  * refactor: re-enable linters, use presets (#866)
  * feat(primary-ip): allow setting auto-delete on create (#860)
  * deps: update dependency golangci/golangci-lint
  * fix(image): only use numerical IDs for label auto-completion
    (#865)
  * add comment
  * disable bugged gosec rule
  * deps: update dependency golangci/golangci-lint to v1.60.3
  * deps: update module golang.org/x/crypto to v0.27.0 (#858)
* Sat Sep 21 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package hcloud-cli: CLI to interact with the Hetzner Cloud
